package com.ruoyi.manage.mapper;

import java.util.List;
import com.ruoyi.manage.domain.RecordStoreCheckInfo;
import org.springframework.stereotype.Repository;
/**
 * 盘点数据记录Mapper接口
 *
 * @author wangh
 * @date 2024-01-22
 */
@Repository
public interface RecordStoreCheckInfoMapper
{
    /**
     * 查询盘点数据记录
     *
     * @param checkId 盘点数据记录主键
     * @return 盘点数据记录
     */
    public RecordStoreCheckInfo selectRecordStoreCheckInfoByCheckId(Long checkId);

    /**
     * 查询盘点数据记录列表
     *
     * @param recordStoreCheckInfo 盘点数据记录
     * @return 盘点数据记录集合
     */
    public List<RecordStoreCheckInfo> selectRecordStoreCheckInfoList(RecordStoreCheckInfo recordStoreCheckInfo);

    /**
     * 新增盘点数据记录
     *
     * @param recordStoreCheckInfo 盘点数据记录
     * @return 结果
     */
    public int insertRecordStoreCheckInfo(RecordStoreCheckInfo recordStoreCheckInfo);

    /**
     * 修改盘点数据记录
     *
     * @param recordStoreCheckInfo 盘点数据记录
     * @return 结果
     */
    public int updateRecordStoreCheckInfo(RecordStoreCheckInfo recordStoreCheckInfo);

    /**
     * 删除盘点数据记录
     *
     * @param checkId 盘点数据记录主键
     * @return 结果
     */
    public int deleteRecordStoreCheckInfoByCheckId(Long checkId);

    /**
     * 批量删除盘点数据记录
     *
     * @param checkIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecordStoreCheckInfoByCheckIds(String[] checkIds);
}
